#
# spec file for package python-Flask-Migrate
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Flask-Migrate
Version:        4.0.7
Release:        1.4
Summary:        SQLAlchemy database migrations for Flask applications using Alembic
License:        MIT
URL:            https://github.com/miguelgrinberg/flask-migrate/
Source:         https://github.com/miguelgrinberg/flask-migrate/archive/refs/tags/v%{version}.tar.gz#/Flask-Migrate-%{version}.tar.gz
BuildRequires:  %{python_module Flask >= 0.9}
BuildRequires:  %{python_module Flask-SQLAlchemy >= 1.0}
BuildRequires:  %{python_module alembic >= 1.9.0}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 0.9
Requires:       python-Flask-SQLAlchemy >= 1.0
Requires:       python-alembic >= 1.9.0
BuildArch:      noarch
%python_subpackages

%description
Flask-Migrate is an extension that handles SQLAlchemy database migrations
for Flask applications using Alembic. The database operations are provided
as command line arguments for Flask-Script.

%prep
%autosetup -p1 -n Flask-Migrate-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/flask_migrate
%{python_sitelib}/Flask_Migrate-%{version}.dist-info

%changelog
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.7:
  * Regression from #438: check `g.x_arg` exists before accessing
    it #541 (commit) (thanks **Skye Im**!)
  * Accept `-x` options for all db commands #438 (commit)
  * Add `--purge` flag to the `stamp` command #540 (commit)
* Mon Feb 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to GitHub tarball, as it includes all test files.
- Drop patch add-custom-template.patch, no longer needed.
- Switch to pyroject macros.
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.5:
  * Compatiblity fixes for Flask-SQLAlchemy >= 3.1
  * Allow process_revision_directives option to be configurable
  * Stop testing Python 3.7, as Flask-SQLAlchemy 3.1 stopped
    supporting it
* Sun May 21 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.4:
  * Correctly obtain database URL with SQLAlchemy 2.0
  * Remove legacy future import in Alembic templates
  * Add SQLAlchemy 1.4 and 2.0 to the test matrix
  * Switch to pytest as test runner
  * Support "check" command
  * Do not use deprecated functions in Flask-SQLAlchemy 3.0
  * Stop building Python 3.6
  * Remove tests from pypi package
* Thu Jan  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.0:
  * Updates for Flask-SQLAlchemy 3.x compatiblity
  * Enable type comparison and batch mode by default
  * Option to rename "db" command group to a custom name
  * Better handling of MetaData instances in templates
  * Set options correctly when revision --autogenerate is used #463
  * Documentation section on configuring Alembic
  * Upgrade build to pypy-3.9
  * Add Python 3.10 to build
  * Add Python 3.11 to build
  * Specify license in project metadata #489
  * Added list-templates command and support for custom templates
  * Alembic templates for aioflask
  * Improved project structure
- Add patch add-custom-template.patch, include custom template so the
  testsuite passes.
- Remove Python 2 gubbins.
- Switch to %%pyunittest macro for running the testsuite.
* Wed Jul 21 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 3.0.1:
  * Add support for Alchemical in addition to Flask-SQLAlchemy
  * Remove Flask-Script references from the documentation
- Changes from 3.0.0:
  * Remove support for Flask-Script
  * Use unittest testrunner
  * Remove dependency on six package
  * Added sphinx build files to .gitignore file
  * Fix Sphinx warning
- Changes from 2.7.0:
  * Reuse engine from Flask-SQLAlchemy
  * Update logging configuration to include Flask-Migrate's logger
- Changes from 2.6.0:
  * Removed deprecated --head-only option
  * Initialize logger with a name
  * Move import to the top in env.py file to avoid linter warnings
  * Add a note to the documentation regarding logging
  * Move builds to GitHub actions
* Mon Mar 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.3:
  * Support for new python interpreters (bsc#1197824)
- Remove merged patch pr_290.patch
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Add pr_290.patch to fix tests to use sys.executable
* Tue May 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.2:
  * add python 3.7 builds, remove 3.4 (commit)
  * auto-generate change log during release (commit)
  * helper release script (commit)
  * support %% character in database URLs #59 (commit)
  * log command output in unit tests (commit)
  * add a section on why use this extension to the docs #101 (commit)
* Sat Feb 16 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 2.4.0:
  * Refreshed the env.py files from the Alembic project (#216)
* Sat Dec  1 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
- update to version 2.3.1:
  * Don't silence transaction errors from SQLAlchemy (#236)
* Wed Oct 24 2018 Antonio Larrosa <alarrosa@suse.com>
- Update to version 2.3.0
  * Use the root logger for alembic error messages
  * Add indicate-current option into history command
* Tue Aug 21 2018 alarrosa@suse.com
- Initial release of python-Flask-Migrate-2.2.1
